@@ -107,6 +107,28 @@ public class ApplicationOptions {
     /** Tree search operation */
     private String treeSearchOperation = TREE_SEARCH_NNI;
 
+    @Override
+    public boolean equals(Object obj) {
+System.out.println("Check equals");
+        if (this == obj) return true;
+        if (obj == null) return false;
+        if (getClass() != obj.getClass()) return false;
+        ApplicationOptions other = (ApplicationOptions) obj;
+        if (align_file == null || other.align_file == null) {
+            return false;
+        } else if (!align_file.equals(other.align_file)) {
+            return false;
+        }
+        if (strategyMode != other.strategyMode) return false;
+        if (ncat != other.ncat) return false;
+        if (tree_file != other.tree_file &&
+              (tree_file == null || !tree_file.equals(other.tree_file)))
+            return false;
+        if (!alignment.equals(other.alignment)) return false;
+        if (!tree.equals(other.tree)) return false;
+        return true;
+    }
+
     /**
      * Sets the number of categories.
      * 
@@ -556,6 +578,12 @@ public class ApplicationOptions {
      */
     public void fillIn(ProtTestArgumentParser arguments) {
 
+    	if(arguments.exists(ProtTestArgumentParser.PARAM_HELP))
+        {
+        	usage();
+        	System.exit(0);
+        }
+    	
         if (arguments.exists(ProtTestArgumentParser.PARAM_ALIGNMENT_FILE)) {
             try {
                 setAlignment(arguments.getValue(ProtTestArgumentParser.PARAM_ALIGNMENT_FILE));
@@ -696,9 +724,10 @@ public class ApplicationOptions {
         println("-------------------------------------------------------------------------------------------------");
         println("Basic usage: ");
         println(" - Sequential version: ");
-        println("        java -jar prottest-2.1.jar -i alignm_file [OPTIONS]");
+        println("        java -jar prottest-"+ProtTest.versionNumber+".jar -i align_file [OPTIONS]");
+        println("        ./prottest3 -i align_file [OPTIONS]");
         println(" - Parallel version: ");
-        println("        mpjrun.sh -wdir $PWD/ -np [NUM_PROCS] -jar prottest-"+ProtTest.versionNumber+".jar -i alignm_file [OPTIONS]");
+        println("        mpjrun.sh -wdir $PWD/ -np [NUM_PROCS] -jar prottest-"+ProtTest.versionNumber+".jar -i align_file [OPTIONS]");
         println("OPTIONS:");
         println(" -i alignment_filename");
         println("            Alignment input file (required)");
@@ -768,9 +797,9 @@ public class ApplicationOptions {
         println("-------------------------------------------------------------------------------------------------");
         println("Example: ");
         println("- Sequential version:");
-        println("    java -jar prottest-"+ProtTest.versionNumber+".jar -i alignm_file -t tree_file -S 0 -all-distributions -F -AIC -BIC -tc 0.5 > output");
+        println("    java -jar prottest-"+ProtTest.versionNumber+".jar -i align_file -t tree_file -S 0 -all-distributions -F -AIC -BIC -tc 0.5 > output");
         println("- Parallel version:");
-        println("    mpjrun.sh -wdir $PWD/ -np 2 -jar prottest-"+ProtTest.versionNumber+".jar -i alignm_file -t tree_file -S 0 -all-distributions -F -AIC -BIC -tc 0.5");
+        println("    mpjrun.sh -wdir $PWD/ -np 2 -jar prottest-"+ProtTest.versionNumber+".jar -i align_file -t tree_file -S 0 -all-distributions -F -AIC -BIC -tc 0.5");
     }
 
     public void reportModelOptimization() {
@@ -828,7 +857,7 @@ public class ApplicationOptions {
         if (!(doAIC|doBIC|doAICc|doDT))
             sb.append(" lnL");
         println("      " + sb.toString());
-        println("    Sample size.................: " + sampleSize + " (not calculated yet)");
+        println("    Sample size.................: " + sampleSize);
         println("  Other options:");
         println("    Display best tree in ASCII..: " + displayASCIITree);
         println("    Display best tree in Newick.: " + displayNewickTree);
